Learn R Programming

nopp (version 1.0.6)

italy2006: 2006 Italian General Election survey

Description

2006 Italian General Election survey, with quadratic ideological proximity.

Usage

data(italy2006)

Arguments

Format

A data frame with 438 observations on the following 18 variables.
country
country name
id
id of respondent
vote
a factor with levels FI UL AN UDC RC for each party voted
self
self-placement of respondent on a 0 to 10 left-right scale
prox_FI
see Details.
prox_UL
see Details.
prox_AN
see Details.
prox_UDC
see Details.
prox_RC
see Details.
partyID_FI
see Details.
partyID_UL
see Details.
partyID_AN
see Details.
partyID_UDC
see Details.
partyID_RC
see Details.
sex
gender variable 1 = female
age
see Details.
education
see Details.
gov_perf
see Details.

CSES - Comparative Study of Electoral Systems: http://www.cses.org/).

Details

In this survey respondents were asked to indicate which party they voted for in the 2006 Election. The data concerns 5 parties: UL (Ulivo), RC (Communist Refoundation party), FI (Forza Italia), AN (National Alliance) and UDC (Union of Christian Democrats).

prox_* quadratic ideological distance between the respondent and a party * placement

partyID_* binary variable equals to 1 if the respondent declares to feel herself close to party *

age : 1 = "18-24 years", 2 = "25-34", 3 = "35-44", 4 = "45-54", 5 = "55-64", 6 = "65 +"

education : 0 = "up to primary school", 1 = "incomplete secondary", 2 = "secondary completed", 3 = "post-secondary trade", 4 = "university undergraduate degree inc", 5 = "university undergraduate degree comp"

gov_perf : 1 = "very good job", 2 = "good job", 3 = "bad job", 4 = "very bad job"

Examples

Run this code
data(italy2006)
head(italy2006)

Run the code above in your browser using DataLab