In this survey respondents were asked to indicate which party they voted for in the 2006 Election. The data concerns 5 parties: UL (Ulivo), RC (Communist Refoundation party), FI (Forza Italia), AN (National Alliance) and UDC (Union of Christian Democrats).
prox_* quadratic ideological distance between the respondent and a party * placement
partyID_* binary variable equals to 1 if the respondent declares to feel herself close to party *
age : 1 = "18-24 years", 2 = "25-34", 3 = "35-44", 4 = "45-54", 5 = "55-64", 6 = "65 +"
education : 0 = "up to primary school", 1 = "incomplete secondary", 2 = "secondary completed", 3 = "post-secondary trade", 4 = "university undergraduate degree inc", 5 = "university undergraduate degree comp"
gov_perf : 1 = "very good job", 2 = "good job", 3 = "bad job", 4 = "very bad job"