data(italy2006.wide)countryidvoteFI UL AN UDC RC for each party votedselfFIDSANDLUDCRCpIDsex1 = femaleageeducationgov_perfvariable from FI to RC identify the placement of those parties, on a 0 to 10 left-right scale, as perceived by the respondent.
pID is a variable that identifies the partisanship of the respondent (where 0=stands for no partyID, 1 = FI partyID, 23 = UL partyID, 3 = AN partyID, 4 = UDC partyID, 6 = RC partyID)
age : 1 = "18-24 years", 2 = "25-34", 3 = "35-44", 4 = "45-54", 5 = "55-64", 6 = "65 +"
education : 0 = "up to primary school", 1 = "incomplete secondary", 2 = "secondary completed", 3 = "post-secondary trade", 4 = "university undergraduate degree inc", 5 = "university undergraduate degree comp"
gov_perf : 1 = "very good job", 2 = "good job", 3 = "bad job", 4 = "very bad job"
data(italy2006.wide)
head(italy2006.wide)
## maybe str(italy2006.wide) ; plot(italy2006.wide) ...
Run the code above in your browser using DataLab