Learn R Programming

nopp (version 1.0.4)

italy2006.wide: 2006 Italian General Election survey

Description

2006 Italian General Election survey - wide format

Usage

data(italy2006.wide)

Arguments

source

CSES - Comparative Study of Electoral Systems: http://www.cses.org/).

Details

In this survey respondents were asked to indicate which party they voted for in the 2006 Election. The data concerns 5 parties: UL (Ulivo), RC (Communist Refoundation party), FI (Forza Italia), AN (National Alliance) and UDC (Union of Christian Democrats). The dataset is in wide format.

variable from FI to RC identify the placement of those parties, on a 0 to 10 left-right scale, as perceived by the respondent.

pID is a variable that identifies the partisanship of the respondent (where 0=stands for no partyID, 1 = FI partyID, 23 = UL partyID, 3 = AN partyID, 4 = UDC partyID, 6 = RC partyID)

age : 1 = "18-24 years", 2 = "25-34", 3 = "35-44", 4 = "45-54", 5 = "55-64", 6 = "65 +"

education : 0 = "up to primary school", 1 = "incomplete secondary", 2 = "secondary completed", 3 = "post-secondary trade", 4 = "university undergraduate degree inc", 5 = "university undergraduate degree comp"

gov_perf : 1 = "very good job", 2 = "good job", 3 = "bad job", 4 = "very bad job"

Examples

Run this code
data(italy2006.wide)
head(italy2006.wide)
## maybe str(italy2006.wide) ; plot(italy2006.wide) ...

Run the code above in your browser using DataLab